Border operation. Adds a coloured border of the given per-side widths around the working image by embedding it in a larger canvas of the border colour.
Summary
Types
@type t() :: %Image.Plug.Pipeline.Ops.Border{ bottom: non_neg_integer(), color: String.t(), left: non_neg_integer(), right: non_neg_integer(), top: non_neg_integer() }